#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                   gi-dbusmenu
version:                0.4.14
visibility:             public
id:                     gi-dbusmenu-0.4.14-Jnow8HnQaw56PdVMsu4Gxj
key:                    gi-dbusmenu-0.4.14-Jnow8HnQaw56PdVMsu4Gxj
license:                LGPL-2.1-only
maintainer:             Iñaki García Etxebarria
author:                 Iñaki García Etxebarria
homepage:               https://github.com/haskell-gi/haskell-gi
synopsis:               Dbusmenu bindings
description:            Bindings for libdbusmenu, autogenerated by haskell-gi.
category:               Bindings
abi:                    450d859d0c985ec7b264f563c93bebb7
exposed:                True
exposed-modules:
    GI.Dbusmenu GI.Dbusmenu.Callbacks GI.Dbusmenu.Config
    GI.Dbusmenu.Constants GI.Dbusmenu.Enums GI.Dbusmenu.Objects
    GI.Dbusmenu.Objects.Client GI.Dbusmenu.Objects.Menuitem
    GI.Dbusmenu.Objects.MenuitemProxy GI.Dbusmenu.Objects.Server

import-dirs:            /usr/lib/ghc-9.6.6/site-local/gi-dbusmenu-0.4.14
library-dirs:
    /usr/lib/ghc-9.6.6/site-local/gi-dbusmenu-0.4.14 /usr/lib

library-dirs-static:
    /usr/lib/ghc-9.6.6/site-local/gi-dbusmenu-0.4.14 /usr/lib

dynamic-library-dirs:   /usr/lib /usr/lib
data-dir:               /usr/share/haskell-gi-dbusmenu
hs-libraries:           HSgi-dbusmenu-0.4.14-Jnow8HnQaw56PdVMsu4Gxj
extra-libraries:        dbusmenu-glib
extra-libraries-static: dbusmenu-glib
include-dirs:           /usr/include/libdbusmenu-glib-0.4
depends:
    base-4.18.2.1 bytestring-0.11.5.3 containers-0.6.7
    gi-glib-2.0.30-5yJXlaDVUzGBmWTtqoVFpO
    gi-gobject-2.0.31-C9Bh9rg3IakITi9bQfpF9x
    haskell-gi-0.26.16-AfWFef96lIi2UboFboEQ6J
    haskell-gi-base-0.26.9-9dGlnSJnubc2h9MiqHeprA
    haskell-gi-overloading-1.0-6w3IXGDooXgu3RA2LfTuf text-2.0.2
    transformers-0.6.1.0

haddock-interfaces:     /usr/share/doc/haskell-gi-dbusmenu/html/gi-dbusmenu.haddock
haddock-html:           /usr/share/doc/haskell-gi-dbusmenu/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

